pub struct LocalNaiveTimeRange {
pub from: LocalNaiveTime,
pub to: LocalNaiveTime,
}Fields
from: LocalNaiveTimeto: LocalNaiveTimeImplementations
Sourceimpl LocalNaiveTimeRange
impl LocalNaiveTimeRange
pub fn crosses_day_boundary(&self) -> bool
Sourcepub fn with_start_date_as_unambiguous_locals(
&self,
nd: NaiveDate,
) -> Option<DateTimeRange<Local>>
pub fn with_start_date_as_unambiguous_locals( &self, nd: NaiveDate, ) -> Option<DateTimeRange<Local>>
Returns None if there is ambiguity (due to daylight savings
time switches, or perhaps leap seconds?). Note that this
literally just adds the given date as the date of the start
time, then if necessary increments the date if the end time <
start time (range crosses a day boundary). Taking the date
from the current time and then passing it to this method means
that the current time can be past the range, and it also means
that even though the current time might be within the range,
the result is in the future (i.e. if the start time of the
range is before a day boundary, this method still resolves it
to the given date, resulting in a time that is in the
future). You probably want to use after_datetime() instead.
Sourcepub fn after_datetime(
&self,
datetime: &DateTime<Local>,
allow_time_inside_range: bool,
) -> Option<DateTimeRange<Local>>
pub fn after_datetime( &self, datetime: &DateTime<Local>, allow_time_inside_range: bool, ) -> Option<DateTimeRange<Local>>
Returns None if there is ambiguity (due to daylight savings
time switches, or perhaps leap seconds?) (or if given a
datetime for which no day can be added (max date?)). If
allow_time_inside_range is true, picks the start date so
that the resulting range contains ndt if possible, otherwise
the resulting range starts >= ndt. XX new desc: the time
period using the self times, closest to datetime, around
it if allowed or closest after it. Does not need to carry the
same date!